@@ -125,13 +125,11 @@ light_theme = {'axes.grid': True,
                'savefig.edgecolor': 'white',
                'savefig.facecolor': 'white',
                'savefig.format': 'png',
-               'savefig.jpeg_quality': 95,
+               # 'savefig.jpeg_quality': 95,
                'savefig.orientation': 'portrait',
                'savefig.pad_inches': 0.1,
-
                }
 
-
 dark_theme = {'axes.facecolor': '#202020',
               'axes.edgecolor': '#FDFDC0',
               'xtick.color': '#FDFDC0',
@@ -770,7 +768,7 @@ class PlotConfig:
             for legline, legtext, mainline in zip(self.mpl_legend.get_lines(),
                                                   self.mpl_legend.get_texts(),
                                                   lins):
-                legline.set_picker(5)
+                legline.set_pickradius(20)
                 legtext.set_picker(5)
                 self.legend_map[legline] = (mainline, legline, legtext)
                 self.legend_map[legtext] = (mainline, legline, legtext)
@@ -836,13 +834,23 @@ class PlotConfig:
 
     def set_viewlimits(self):
         all_limits = []
-
+        x_minpos = None
+        y_minpos = None
         for ax in self.canvas.figure.get_axes():
             limits = [None, None, None, None]
             if ax in self.axes_traces:
                 try:
                     for trace, lines in enumerate(ax.get_lines()):
                         x, y = lines.get_xdata(), lines.get_ydata()
+                        if y_minpos is None:
+                            y_minpos= min(y[np.where(y>0)])
+                        else:
+                            y_minpos= min(y_minpos, min(y[np.where(y>0)]))
+                        if x_minpos is None:
+                            x_minpos= min(x[np.where(x>0)])
+                        else:
+                            x_minpos= min(x_minpos, min(x[np.where(x>0)]))
+                            
                         if limits == [None, None, None, None]:
                             limits = [min(x), max(x), min(y), max(y)]
                         else:
@@ -852,7 +860,8 @@ class PlotConfig:
                                       max(limits[3], max(y))]
                 except ValueError:
                     pass
-
+            if x_minpos is None: x_minpos = 1.e-8
+            if y_minpos is None: y_minpos = 1.e-8
             if ax in self.user_limits:
                 for i, val in  enumerate(self.user_limits[ax]):
                     if val is not None:
@@ -878,9 +887,11 @@ class PlotConfig:
                 limits[2] = limits[2] - yrange * self.viewpad /100.0
                 limits[3] = limits[3] + yrange * self.viewpad /100.0
                 if self.xscale == 'log':
-                    limits[0] = max(0, limits[0])
+                    limits[0] = max(x_minpos/2, limits[0])
+                   
                 if self.yscale == 'log':
-                    limits[2] = max(0, limits[2])
+                    limits[2] = max(y_minpos/2, limits[2])
+                   
 
             if ax in self.user_limits:
                 for i, val in  enumerate(self.user_limits[ax]):
@@ -907,11 +918,11 @@ class PlotConfig:
         self.yscale = yscale
         for axes in self.canvas.figure.get_axes():
             try:
-                axes.set_yscale(yscale, basey=10)
+                axes.set_yscale(yscale)
             except:
                 axes.set_yscale('linear')
             try:
-                axes.set_xscale(xscale, basex=10)
+                axes.set_xscale(xscale)
             except:
                 axes.set_xscale('linear')
         if not delay_draw:
